@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with Jade; see the file COPYING.	If not, write to
-   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #define _GNU_SOURCE
 
